@@ -28,7 +28,16 @@ username = getpass.getuser()
 # except:
 #     pass
 
-SAVE_DIR = f'/Users/{username}/pyserved'
+import platform; osofmachine = platform.system().lower()
+
+if osofmachine == "windows":
+    SAVE_DIR = r"C:\Users\{username}\pyserved".format(username=username)
+elif osofmachine=="darwin":
+    SAVE_DIR = f"/Users/{username}/pyserved"
+elif osofmachine=="linux":
+    SAVE_DIR = f"/Users/{username}/pyserved"
+
+# SAVE_DIR = f'/Users/{username}/pyserved'
 
 try:
     os.mkdir(SAVE_DIR)
@@ -37,13 +46,18 @@ except OSError as exc:
         raise
     pass
 
+
 random_num = random.randint(1000, 9999)
 name = f"copiedfile{random_num}"
 
 # ni.ifaddresses('eth0')
 print("______________________________________________________")
 print("")
-print("You can find out the ip address by typing\n \n $ ifconfig en1 \n\n or \n\n $ ifconfig en0\n\n or you can search google for it.\n\n")
+if osofmachine == 'darwin' or osofmachine == 'linux':
+    print("You can find out the ip address by typing\n \n $ ifconfig en1 \n\n or \n\n $ ifconfig en0\n\n or you can search google for it.\n\n")
+elif osofmachine=="windows":
+    print("You can find out the ip address by using \n \n $ ipconfig \n\n")
+
 SERVER = input('Server HOST on which you want to run: ')
 
 # SERVER = socket.gethostbyname(socket.getfqdn())
